"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const ClickAwayListener_1 = tslib_1.__importDefault(require("@material-ui/core/ClickAwayListener"));
const TextField_1 = tslib_1.__importDefault(require("@material-ui/core/TextField"));
const Typography_1 = tslib_1.__importDefault(require("@material-ui/core/Typography"));
const react_1 = tslib_1.__importDefault(require("react"));
const react_redux_1 = require("react-redux");
const client_utils_1 = require("@sensenet/client-utils");
const store_1 = require("../../store");
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
exports.mapStateToProps = (state) => {
    return {
        documentName: state.sensenetDocumentViewer.documentState.document.documentName,
        activePages: state.sensenetDocumentViewer.viewer.activePages,
        pageCount: state.sensenetDocumentViewer.documentState.document.pageCount,
        gotoPage: state.sensenetDocumentViewer.localization.gotoPage,
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
exports.mapDispatchToProps = {
    setActivePages: store_1.setActivePages,
};
/**
 * Document widget component for paging
 */
class DocumentTitlePagerComponent extends react_1.default.Component {
    constructor() {
        super(...arguments);
        /** the component state */
        this.state = {
            currentPage: this.props.activePages[0] || 1,
            lastPage: this.props.pageCount,
            focused: false,
        };
        this.setPage = client_utils_1.debounce(() => {
            this.props.setActivePages([this.state.currentPage]);
        }, 200).bind(this);
    }
    /** triggered when the component will receive props */
    static getDerivedStateFromProps(nextProps, lastState) {
        const newState = Object.assign({}, lastState, { lastPage: nextProps.pageCount });
        return newState;
    }
    /**
     * sets the page to the specified value
     * @param page
     */
    gotoPage(page) {
        let pageInt = typeof page === 'string' ? parseInt(page, 10) : page;
        if (!isNaN(pageInt)) {
            pageInt = Math.max(pageInt, 1);
            pageInt = Math.min(pageInt, this.props.pageCount);
            this.setState({
                currentPage: pageInt,
            }, () => {
                this.setPage();
            });
        }
    }
    handleFocused() {
        this.setState(Object.assign({}, this.state, { focused: true }));
    }
    handleBlur() {
        this.setState(Object.assign({}, this.state, { focused: false }));
    }
    /**
     * renders the component
     */
    render() {
        return (react_1.default.createElement(ClickAwayListener_1.default, { onClickAway: () => this.handleBlur() },
            react_1.default.createElement(Typography_1.default, { onClick: () => this.handleFocused(), variant: "h6", color: "inherit", style: { cursor: 'pointer', display: 'flex', alignItems: 'center', overflow: 'hidden', margin: '0 2.5em' }, title: this.props.documentName },
                react_1.default.createElement("div", { style: { whiteSpace: 'nowrap', overflow: 'hidden', textOverflow: 'ellipsis' } },
                    this.props.documentName,
                    "\u00A0"),
                this.state.focused ? (react_1.default.createElement("form", { onSubmit: event => event.preventDefault() },
                    react_1.default.createElement(TextField_1.default, { style: { flexShrink: 0 }, title: this.props.gotoPage, defaultValue: this.state.currentPage, onChange: ev => this.gotoPage(ev.currentTarget.value), type: "number", required: true, InputLabelProps: {
                            shrink: true,
                        }, inputProps: {
                            min: 1,
                            max: this.state.lastPage,
                            style: { textAlign: 'center' },
                        }, margin: "dense" }))) : (react_1.default.createElement("div", { style: { flexShrink: 0 } },
                    this.props.activePages[0],
                    " / ",
                    this.props.pageCount)))));
    }
}
exports.DocumentTitlePagerComponent = DocumentTitlePagerComponent;
const connectedComponent = react_redux_1.connect(exports.mapStateToProps, exports.mapDispatchToProps)(DocumentTitlePagerComponent);
exports.DocumentTitlePager = connectedComponent;
//# sourceMappingURL=DocumentTitlePager.js.map